@@ -1,9 +1,9 @@
 /* Error handler for noninteractive utilities
-   Copyright (C) 1990,91,92,93,94,95,96,97,98 Free Software Foundation, Inc.
+   Copyright (C) 1990-1998, 2000, 2001 Free Software Foundation, Inc.
 
 
    NOTE: The canonical source of this file is maintained with the GNU C Library.
-   Bugs can be reported to bug-glibc@prep.ai.mit.edu.
+   Bugs can be reported to bug-glibc@gnu.org.
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -51,7 +51,14 @@ void exit ();
 #include "error.h"
 
 #ifndef _
-# define _(String) String
+# if ENABLE_NLS || defined _LIBC
+#  include <libintl.h>
+#  ifndef _
+#   define _(Str) gettext (Str)
+#  endif
+# else
+#  define _(Str) (Str)
+# endif
 #endif
 
 /* If NULL, error will flush stdout, then print on stderr the program
@@ -77,6 +84,11 @@ unsigned int error_message_count;
 # define error __error
 # define error_at_line __error_at_line
 
+# ifdef USE_IN_LIBIO
+# include <libio/iolibio.h>
+#  define fflush(s) _IO_fflush (s)
+# endif
+
 #else /* not _LIBC */
 
 /* The calling program should define program_name and set it to the
@@ -151,7 +163,7 @@ error (status, errnum, message, va_alist)
   ++error_message_count;
   if (errnum)
     {
-#if defined HAVE_STRERROR_R || defined _LIBC
+#if defined HAVE_STRERROR_R || _LIBC
       char errbuf[1024];
       fprintf (stderr, ": %s", __strerror_r (errnum, errbuf, sizeof errbuf));
 #else
@@ -226,7 +238,7 @@ error_at_line (status, errnum, file_name, line_number, message, va_alist)
   ++error_message_count;
   if (errnum)
     {
-#if defined HAVE_STRERROR_R || defined _LIBC
+#if defined HAVE_STRERROR_R || _LIBC
       char errbuf[1024];
       fprintf (stderr, ": %s", __strerror_r (errnum, errbuf, sizeof errbuf));
 #else
