@@ -1,5 +1,5 @@
 /* GNU gettext - internationalization aids
-   Copyright (C) 1996, 1998 Free Software Foundation, Inc.
+   Copyright (C) 1996, 1998, 2000 Free Software Foundation, Inc.
 
    This file was written by Peter Miller <millerp@canb.auug.org.au>
 
@@ -20,7 +20,14 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #ifndef SRC_DIR_LIST_H
 #define SRC_DIR_LIST_H
 
-void dir_list_append PARAMS ((const char *__directory));
-const char *dir_list_nth PARAMS ((int __n));
+/* Management of the list of directories where PO files are searched.
+   It is an ordered list, without duplicates.  The default value of the
+   list consists of the single directory ".".  */
+
+/* Append a directory to the end of the list of directories.  */
+extern void dir_list_append PARAMS ((const char *__directory));
+
+/* Return the nth directory, or NULL of n is out of range.  */
+extern const char *dir_list_nth PARAMS ((int __n));
 
 #endif /* SRC_DIR_LIST_H */
